%% PLOT_RESPONSE
% Plots the response of variables in the Matlab workspace.
%
%% Load sample data from MAT files
% Comment these lines out if you want to use the data recently stored in
% the data_pos and data_vm variables from after running the controller.
% load('data_impl_fsf_theta_x.mat');
% load('data_impl_fsf_theta_y.mat');
% load('data_impl_fsf_alpha_x.mat');
% load('data_impl_fsf_alpha_y.mat');
% load('data_impl_fsf_Vm.mat');
%
%% Setup variables
% Load from variables set in workspace after running a Simulink model or
% from the previously saved response saved in the MAT files above.
t = data_theta_x(:,1);          % time (s)
th_x_d = data_theta_x(:,2);     % setpoint
th_x = data_theta_x(:,3);       % measured process variable
a_x = data_alpha_x(:,2);        % pendulum x angle
th_y_d = data_theta_y(:,2);     % setpoint
th_y = data_theta_y(:,3);       % measured process variable
a_y = data_alpha_y(:,2);        % pendulum y angle
u_x = data_Vm(:,2);           % input signal, srv02 x
u_y = data_Vm(:,3);           % input signal, srv02 y
%
%% Plot response
figure(1)
subplot(3,1,1);
plot(t,th_x_d,'b:',t,th_x,'r-','linewidth',2);
ylabel('\theta_x (deg)');
% axis([0 10 -10 10]);
subplot(3,1,2);
plot(t,a_x,'r-','linewidth',2);
ylabel('\alpha_x (deg)');
% axis([0 10 -10 10]);
subplot(3,1,3);
plot(t,u_x,'r-','linewidth',2);
ylabel('V_{m,x} (V)');
xlabel('time (s)');
% axis([0 10 -5 5 ]);

figure(2);
subplot(3,1,1);
plot(t,th_y_d,'b:',t,th_y,'r-','linewidth',2);
ylabel('\theta_y (deg)');
% axis([0 10 -10 10]);
subplot(3,1,2);
plot(t,a_y,'r-','linewidth',2);
ylabel('\alpha_y (deg)');
% axis([0 10 -10 10]);
subplot(3,1,3);
plot(t,u_y,'r-','linewidth',2);
ylabel('V_{m,y} (V)');
xlabel('time (s)');
% axis([0 10 -5 5 ]);

% Find specifications
c_ts = 0.04;
tol_p = 360/4096;
[ tp_x, ts_x, e_ss_x, PO_x ] = meas_step_rsp_specs( t, th_x_d, th_x, c_ts, tol_p );
[ tp_y, ts_y, e_ss_y, PO_y ] = meas_step_rsp_specs( t, th_y_d, th_y, c_ts, tol_p );

e_ss_x
ts_x
PO_x
max_alpha_x = max(abs(a_x))

e_ss_y
ts_y
PO_y
max_alpha_y = max(abs(a_y))

% rm: un-comment to save variables to MAT files
% full-state feedback response
% save('data_impl_fsf_theta_x.mat','data_theta_x');
% save('data_impl_fsf_theta_y.mat','data_theta_y');
% save('data_impl_fsf_alpha_x.mat','data_alpha_x');
% save('data_impl_fsf_alpha_y.mat','data_alpha_y');
% save('data_impl_fsf_vm.mat','data_Vm');
% partial-state feedback response
% save('data_impl_psf_theta_x.mat','data_theta_x');
% save('data_impl_psf_theta_y.mat','data_theta_y');
% save('data_impl_psf_alpha_x.mat','data_alpha_x');
% save('data_impl_psf_alpha_y.mat','data_alpha_y');
% save('data_impl_psf_vm.mat','data_Vm');

