%% SETUP_SRV02_EXP14_2D_GANTRY
%
% Sets the necessary parameters to run the SRV02 Experiment #13: Position
% Control of 2-DOF Robot laboratory using the "s_srv02_2d_robot" and
% "q_srv02_2d_robot" Simulink diagrams.
% 
% Copyright (C) 2008 Quanser Consulting Inc.
%
clear all;
%
%% SRV02 Configuration
% External Gear Configuration: set to 'HIGH' or 'LOW'
EXT_GEAR_CONFIG = 'HIGH';
% Encoder Type: set to 'E' or 'EHR'
ENCODER_TYPE = 'E';
% Is SRV02 equipped with Tachometer? (i.e. option T): set to 'YES' or 'NO'
TACH_OPTION = 'YES';
% Type of Load: set to 'NONE', 'DISC', or 'BAR'
LOAD_TYPE = 'NONE';
% Amplifier Gain used: 
% VoltPAQ-X1 users: set to K_AMP to 1 and Gain switch on amplifier to 1
% VoltPAQ-X2 users: set to K_AMP 3
K_AMP = 1;
% Amplifier Type: set to 'VoltPAQ'
AMP_TYPE = 'VoltPAQ';
% Digital-to-Analog Maximum Voltage (V)
VMAX_DAC = 10;
%
%% System Parameters
% Set SRV02 Base Unit model parameters (based on configuration set by user)
[ Rm, kt, km, Kg, eta_g, Beq, Jm, Jeq, eta_m, K_POT, K_TACH, K_ENC, VMAX_AMP, IMAX_AMP ] = config_srv02( EXT_GEAR_CONFIG, ENCODER_TYPE, TACH_OPTION, AMP_TYPE, LOAD_TYPE );
% Sets model variables according to the user-defined pendulum configuration
% Load rotary arm parameters
[ g, Mr, Lr, lr, Jl, Dr ] = config_sp( 'ROTARY_ARM', 'ROTPEN-E' );
% Load medium 12-inch pendulum parameters
[ g, Mp, Lp, lp, Jp, Dp ] = config_sp( 'MEDIUM_12IN', 'ROTPEN-E' );
% Load 2-DOF Gantry parameters: link length, re-calculated equivalent 
% moment of inertia acting on the servo load, and sensor gains.
[ Lb, Jr, K_POT_2DP, K_ENC_2DP ] = config_2d_gantry( Jeq );
% Length of 'rotary arm' for 2DSPG is the approx hypotenuse of two arm links
Lr = sqrt(Lb^2+Lb^2);
% Set Open-loop state-space model of rotary single inverted pendulum
SPG_ABCD_eqns;
% Initial state
X0 = [0, 0, 0, 0];
%
%% Filter Parameters
% SRV02 High-pass filter in PD control used to compute velocity
% Cutoff frequency (rad/s)
wcf_1 = 2 * pi * 50.0;
% Pendulum High-pass filter in PD control used to compute velocity
% Cutoff frequency (rad/s)
wcf_2 = 2 * pi * 15.0;
%
%% Calculate Control Parameters
% Set LQR weighting matrices.
% Q = diag( [1000 0 25 250] );
Q = diag( [250 0 5 10] );
% impl
% Q = diag( [250 0 0 5] );
R = 1;
% Calculate control gain using LQR optimization.
[K,S,E] = lqr(A,B,Q,R);
%
%% Display
disp( ' ' );
disp( 'Control gain: ' )
K